==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/id-ID.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH.mm.ss",
    Ed => "E, d",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'minggu' 'ke'-W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss. a v",
    hmv => "h.mm a v",
    ms => "mm.ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'minggu' 'ke'-w Y",
  },
  code => "id-ID",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Sen",
    "Sel",
    "Rab",
    "Kam",
    "Jum",
    "Sab",
    "Min",
  ],
  day_format_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_format_wide => [
    "Senin",
    "Selasa",
    "Rabu",
    "Kamis",
    "Jumat",
    "Sabtu",
    "Minggu",
  ],
  day_stand_alone_abbreviated => [
    "Sen",
    "Sel",
    "Rab",
    "Kam",
    "Jum",
    "Sab",
    "Min",
  ],
  day_stand_alone_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "Senin",
    "Selasa",
    "Rabu",
    "Kamis",
    "Jumat",
    "Sabtu",
    "Minggu",
  ],
  era_abbreviated => [
    "SM",
    "M",
  ],
  era_narrow => [
    "SM",
    "M",
  ],
  era_wide => [
    "Sebelum Masehi",
    "Masehi",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %r %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Indonesian",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Agu",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Maret",
    "April",
    "Mei",
    "Juni",
    "Juli",
    "Agustus",
    "September",
    "Oktober",
    "November",
    "Desember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Agu",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Maret",
    "April",
    "Mei",
    "Juni",
    "Juli",
    "Agustus",
    "September",
    "Oktober",
    "November",
    "Desember",
  ],
  name => "Indonesian Indonesia",
  native_language => "Indonesia",
  native_name => "Indonesia Indonesia",
  native_script => undef,
  native_territory => "Indonesia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kuartal ke-1",
    "Kuartal ke-2",
    "Kuartal ke-3",
    "Kuartal ke-4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kuartal ke-1",
    "Kuartal ke-2",
    "Kuartal ke-3",
    "Kuartal ke-4",
  ],
  script => undef,
  territory => "Indonesia",
  time_format_full => "HH.mm.ss zzzz",
  time_format_long => "HH.mm.ss z",
  time_format_medium => "HH.mm.ss",
  time_format_short => "HH.mm",
  variant => undef,
  version => 35,
}

==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/id-ID.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH.mm.ss",
    Ed => "E, d",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "'minggu' 'ke'-W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss. a v",
    hmv => "h.mm a v",
    ms => "mm.ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'minggu' 'ke'-w Y",
  },
  code => "id-ID",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Sen",
    "Sel",
    "Rab",
    "Kam",
    "Jum",
    "Sab",
    "Min",
  ],
  day_format_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_format_wide => [
    "Senin",
    "Selasa",
    "Rabu",
    "Kamis",
    "Jumat",
    "Sabtu",
    "Minggu",
  ],
  day_stand_alone_abbreviated => [
    "Sen",
    "Sel",
    "Rab",
    "Kam",
    "Jum",
    "Sab",
    "Min",
  ],
  day_stand_alone_narrow => [
    "S",
    "S",
    "R",
    "K",
    "J",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "Senin",
    "Selasa",
    "Rabu",
    "Kamis",
    "Jumat",
    "Sabtu",
    "Minggu",
  ],
  era_abbreviated => [
    "SM",
    "M",
  ],
  era_narrow => [
    "SM",
    "M",
  ],
  era_wide => [
    "Sebelum Masehi",
    "Masehi",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %r %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %r",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Indonesian",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Agu",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Maret",
    "April",
    "Mei",
    "Juni",
    "Juli",
    "Agustus",
    "September",
    "Oktober",
    "November",
    "Desember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Agu",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Maret",
    "April",
    "Mei",
    "Juni",
    "Juli",
    "Agustus",
    "September",
    "Oktober",
    "November",
    "Desember",
  ],
  name => "Indonesian Indonesia",
  native_language => "Indonesia",
  native_name => "Indonesia Indonesia",
  native_script => undef,
  native_territory => "Indonesia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kuartal ke-1",
    "Kuartal ke-2",
    "Kuartal ke-3",
    "Kuartal ke-4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kuartal ke-1",
    "Kuartal ke-2",
    "Kuartal ke-3",
    "Kuartal ke-4",
  ],
  script => undef,
  territory => "Indonesia",
  time_format_full => "HH.mm.ss zzzz",
  time_format_long => "HH.mm.ss z",
  time_format_medium => "HH.mm.ss",
  time_format_short => "HH.mm",
  variant => undef,
  version => 39,
}
